..
      Copyright 2010-2011 United States Government as represented by the
      Administrator of the National Aeronautics and Space Administration.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Contributor Guide
=================

In this section you will find information on how to contribute to Cinder.
Content includes architectural overviews, tips and tricks for setting up a
development environment, and information on Cinder's lower level programming
APIs.

Getting Started
---------------
.. toctree::
    :maxdepth: 2

    contributing
    backporting
    releases
    documentation

Writing Release Notes
---------------------

Please follow the format, it will make everyone's life easier.  There's
even a special section on writing release notes for Cinder drivers.

.. toctree::
    :maxdepth: 2

    releasenotes

.. _programming-howtos:

Programming HowTos and Tutorials
--------------------------------
.. toctree::
    :maxdepth: 2

    development.environment
    testing
    api_microversion_dev
    api_conditional_updates
    addmethod.openstackapi
    drivers
    high_availability
    gmr
    replication
    user_messages
    migration
    api.apache
    rolling.upgrades
    groups
    database-migrations

.. _managing-development:

Managing the Development Cycle
------------------------------
.. toctree::
   :maxdepth: 1

   releasecycle
   cinder-groups

Documentation Contribution
--------------------------
.. toctree::
   :maxdepth: 2

   documentation

.. _background-concepts:

Background Concepts for Cinder
------------------------------
.. toctree::
   :maxdepth: 3

   architecture
   attach_detach_conventions
   attach_detach_conventions_v2
   thin_provisioning
   threading
   i18n
   rpc

Other Resources
---------------
.. toctree::
   :maxdepth: 3

   launchpad
   gerrit
   zuul
   releasenotes

   Module Reference <api/modules>

.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`

